==> sdc-cms-editing-5.0.2.tgz: package/es/components/editing/EntryDate.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React from 'react';
import { inject, observer } from 'mobx-react';

import moment from 'moment';

import { DatePicker } from '../date/DatePicker';

import { fieldValue } from '../../data';

var EntryDate = inject('store')(observer(function (_ref) {
  var field = _ref.field,
      store = _ref.store,
      props = _objectWithoutProperties(_ref, ['field', 'store']);

  if (field.dataType !== 'date') {
    return null;
  }

  var value = fieldValue(store._sending, field.key);
  if (!field.editable) {
    return value ? moment(value).format(field.display || 'DD.MM.YYYY') : null;
  }

  var current = moment(value).toDate();

  var handleChange = function handleChange(value) {
    var date = moment(value, 'YYYY-MM-DD');
    console.log(date);
    store.updateFieldWith(field, {}, date.toDate().valueOf(), true);
  };

  return React.createElement(DatePicker, _extends({ format: field.display || 'DD.MM.YYYY',
    value: current, time: false,
    onFocus: store.selectField(field),
    onChange: handleChange
  }, props));
}));
export { EntryDate };

==> sdc-cms-editing-5.1.15.tgz: package/es/components/editing/EntryDate.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React from 'react';
import { inject, observer } from 'mobx-react';

import moment from 'moment';

import { DatePicker } from '../date/DatePicker';

import { fieldValue } from 'sdc-data-models';

var EntryDate = inject('store')(observer(function (_ref) {
  var field = _ref.field,
      store = _ref.store,
      props = _objectWithoutProperties(_ref, ['field', 'store']);

  if (field.dataType !== 'date') {
    return null;
  }

  var value = fieldValue(store._sending, field.key);
  if (!field.editable) {
    return value ? moment(value).format(field.display || 'DD.MM.YYYY') : null;
  }

  var current = moment(value).toDate();

  var handleChange = function handleChange(value) {
    var date = moment(value, 'YYYY-MM-DD');
    console.log(date);
    store.updateFieldWith(field, {}, date.toDate().valueOf(), true);
  };

  return React.createElement(DatePicker, _extends({ format: field.display || 'DD.MM.YYYY',
    value: current,
    onFocus: store.selectField(field),
    onChange: handleChange
  }, props));
}));
export { EntryDate };
